from ...utils.abbreviated_enum import AbbreviatedEnum


class WeatherOptions(AbbreviatedEnum):
    dry = ("Dry", "1")
    heavy_rain = ("Heavy Rain", "2")
    light_rain = ("Light Rain", "3")
    snow = ("Snow", "4")
    dry_weather_wet_ground = ("Dry Weather/Wet Ground", "5")
